summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/svnfrontend/tdesvnfilelist.cpp8
-rw-r--r--src/tdeiosvn/tdeiobytestream.cpp (renamed from src/tdeiosvn/kiobytestream.cpp)2
-rw-r--r--src/tdeiosvn/tdeiobytestream.h (renamed from src/tdeiosvn/kiobytestream.h)0
-rw-r--r--src/tdeiosvn/tdeiolistener.cpp (renamed from src/tdeiosvn/kiolistener.cpp)6
-rw-r--r--src/tdeiosvn/tdeiolistener.h (renamed from src/tdeiosvn/kiolistener.h)0
-rw-r--r--src/tdeiosvn/tdeiosvn.cpp4
-rw-r--r--src/tdeiosvn/tdeiosvn.h4
7 files changed, 12 insertions, 12 deletions
diff --git a/src/svnfrontend/tdesvnfilelist.cpp b/src/svnfrontend/tdesvnfilelist.cpp
index 6af7c8f..2625951 100644
--- a/src/svnfrontend/tdesvnfilelist.cpp
+++ b/src/svnfrontend/tdesvnfilelist.cpp
@@ -1988,12 +1988,12 @@ void tdesvnfilelist::slotDelete()
TQValueList<svn::Path> items;
TQStringList displist;
- KURL::List kioList;
+ KURL::List tdeioList;
while ((cur=liter.current())!=0){
++liter;
if (!cur->isRealVersioned()) {
KURL _uri; _uri.setPath(cur->fullName());
- kioList.append(_uri);
+ tdeioList.append(_uri);
} else {
items.push_back(cur->fullName());
}
@@ -2003,8 +2003,8 @@ void tdesvnfilelist::slotDelete()
if (answer!=KMessageBox::Yes) {
return;
}
- if (kioList.count()>0) {
- TDEIO::Job*aJob = TDEIO::del(kioList);
+ if (tdeioList.count()>0) {
+ TDEIO::Job*aJob = TDEIO::del(tdeioList);
connect(aJob,TQT_SIGNAL(result (TDEIO::Job *)),this,TQT_SLOT(slotDeleteFinished(TDEIO::Job*)));
dispDummy();
}
diff --git a/src/tdeiosvn/kiobytestream.cpp b/src/tdeiosvn/tdeiobytestream.cpp
index 81c6fc8..fe3c3a9 100644
--- a/src/tdeiosvn/kiobytestream.cpp
+++ b/src/tdeiosvn/tdeiobytestream.cpp
@@ -17,7 +17,7 @@
* Free Software Foundation, Inc., *
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#include "kiobytestream.h"
+#include "tdeiobytestream.h"
KioByteStream::KioByteStream(StreamWrittenCb*aCb,const TQString&filename)
: svn::stream::SvnStream(false,true,0L),
diff --git a/src/tdeiosvn/kiobytestream.h b/src/tdeiosvn/tdeiobytestream.h
index 48addfe..48addfe 100644
--- a/src/tdeiosvn/kiobytestream.h
+++ b/src/tdeiosvn/tdeiobytestream.h
diff --git a/src/tdeiosvn/kiolistener.h b/src/tdeiosvn/tdeiolistener.h
index f836b65..f836b65 100644
--- a/src/tdeiosvn/kiolistener.h
+++ b/src/tdeiosvn/tdeiolistener.h
diff --git a/src/tdeiosvn/tdeiosvn.cpp b/src/tdeiosvn/tdeiosvn.cpp
index fe17ab1..1365dd2 100644
--- a/src/tdeiosvn/tdeiosvn.cpp
+++ b/src/tdeiosvn/tdeiosvn.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "tdesvn-config.h"
#include "tdeiosvn.h"
-#include "kiolistener.h"
+#include "tdeiolistener.h"
#include "svnqttypes.hpp"
#include "dirent.hpp"
@@ -147,7 +147,7 @@ tdeio_svnProtocol::tdeio_svnProtocol(const TQCString &pool_socket, const TQCStri
tdeio_svnProtocol::~tdeio_svnProtocol()
{
- kdDebug()<<"Delete kio protocol"<<endl;
+ kdDebug()<<"Delete tdeio protocol"<<endl;
delete m_pData;
}
diff --git a/src/tdeiosvn/tdeiosvn.h b/src/tdeiosvn/tdeiosvn.h
index eca379a..b63936c 100644
--- a/src/tdeiosvn/tdeiosvn.h
+++ b/src/tdeiosvn/tdeiosvn.h
@@ -20,7 +20,7 @@
#ifndef KIOSVN_H
#define KIOSVN_H
-#include "kiobytestream.h"
+#include "tdeiobytestream.h"
#include <tqstring.h>
#include <tqcstring.h>
@@ -64,7 +64,7 @@ public:
virtual void wc_delete(const KURL::List&);
virtual void special(const TQByteArray& data);
virtual void wc_resolve(const KURL&,bool);
- /* looked on kio::svn from tdesdk */
+ /* looked on tdeio::svn from tdesdk */
enum KSVN_METHOD {
/* KURL repository, KURL target, int revnumber, TQString revkind */
SVN_CHECKOUT = 1,
diff --git a/src/tdeiosvn/kiolistener.cpp b/src/tdeiosvn/tdeiolistener.cpp
index f4cd940..d8d3210 100644
--- a/src/tdeiosvn/kiolistener.cpp
+++ b/src/tdeiosvn/tdeiolistener.cpp
@@ -17,7 +17,7 @@
* Free Software Foundation, Inc., *
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#include "kiolistener.h"
+#include "tdeiolistener.h"
#include "tdeiosvn.h"
#include <kdebug.h>
@@ -98,12 +98,12 @@ bool KioListener::contextGetLogMessage (TQString & msg,const svn::CommitItemList
}
msg = lt[0];
#else
- msg = "Made with a kio::svn client";
+ msg = "Made with a tdeio::svn client";
#endif
return true;
}
/*! the content of that method is taken from the notify in kio::svn in KDE SDK */
/* this moment we don't use it full 'cause not all is made via KIO */
void KioListener::contextNotify (const char * path,svn_wc_notify_action_t action,svn_node_kind_t kind ,const char * mime_type ,svn_wc_notify_state_t content_state, svn_wc_notify_state_t prop_state,svn_revnum_t revision)
{
@@ -98,12 +98,12 @@ bool KioListener::contextGetLogMessage (TQString & msg,const svn::CommitItemList
return true;
}
-/*! the content of that method is taken from the notify in kio::svn in KDE SDK */
+/*! the content of that method is taken from the notify in tdeio::svn in KDE SDK */
/* this moment we don't use it full 'cause not all is made via KIO */
void KioListener::contextNotify (const char * path,svn_wc_notify_action_t action,svn_node_kind_t kind ,const char * mime_type ,svn_wc_notify_state_t content_state, svn_wc_notify_state_t prop_state,svn_revnum_t revision)